/**
 * @author @thkruz Theodore Kruczek
 * @license AGPL-3.0-or-later
 * @copyright (c) 2020-2024 Theodore Kruczek
 *
 * Orbital Object ToolKit is free software: you can redistribute it and/or modify it under the
 * terms of the GNU Affero General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * Orbital Object ToolKit is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with
 * Orbital Object ToolKit. If not, see <http://www.gnu.org/licenses/>.
 */
import { EpochUTC, J2000, Kilometers, KilometersPerSecond, Matrix, RadiansPerSecond, Seconds, Vector3D } from 'ootk-core';
import { Thrust } from './../force/Thrust.js';
import { Waypoint } from './../maneuver/Waypoint.js';
export declare class Hill {
    epoch: EpochUTC;
    position: Vector3D<Kilometers>;
    velocity: Vector3D<KilometersPerSecond>;
    private semimajorAxis_;
    private meanMotion_;
    constructor(epoch: EpochUTC, position: Vector3D<Kilometers>, velocity: Vector3D<KilometersPerSecond>, semimajorAxis: Kilometers);
    static fromState(origin: J2000, radialPosition: Kilometers, intrackPosition: Kilometers, nodeVelocity: KilometersPerSecond, nodeOffsetTime: Seconds): Hill;
    static fromNmc(origin: J2000, majorAxisRange: Kilometers, nodeVelocity: KilometersPerSecond, nodeOffsetTime: Seconds, translation?: number): Hill;
    static fromPerch(origin: J2000, perchRange: Kilometers, nodeVelocity: KilometersPerSecond, nodeOffsetTime: Seconds): Hill;
    get semimajorAxis(): Kilometers;
    set semimajorAxis(sma: Kilometers);
    get meanMotion(): RadiansPerSecond;
    toJ2000Matrix(origin: J2000, transform: Matrix): J2000;
    toJ2000(origin: J2000): J2000;
    static transitionMatrix(t: number, meanMotion: number): Matrix;
    transition(t: Seconds): Hill;
    transitionWithMatrix(stm: Matrix, t: Seconds): Hill;
    propagate(newEpoch: EpochUTC): Hill;
    propagateWithMatrix(stm: Matrix, newEpoch: EpochUTC): Hill;
    maneuver(maneuver: Thrust): Hill;
    ephemeris(start: EpochUTC, stop: EpochUTC, step?: Seconds): Hill[];
    get period(): Seconds;
    nextRadialTangent(): Hill;
    solveManeuver(waypoint: Waypoint, ignoreCrosstrack?: boolean): Thrust;
    maneuverSequence(pivot: EpochUTC, waypoints: Waypoint[], preManeuvers?: Thrust[], postManeuvers?: Thrust[]): Thrust[];
    maneuverOrigin(maneuver: Thrust): Hill;
    get name(): string;
    toString(): string;
}
