/**
 * @author @thkruz Theodore Kruczek
 * @license AGPL-3.0-or-later
 * @copyright (c) 2020-2024 Theodore Kruczek
 *
 * Orbital Object ToolKit is free software: you can redistribute it and/or modify it under the
 * terms of the GNU Affero General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * Orbital Object ToolKit is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with
 * Orbital Object ToolKit. If not, see <http://www.gnu.org/licenses/>.
 */
import { Epoch, EpochUTC, J2000 } from 'ootk-core';
import { ForceModel } from '../force/ForceModel.js';
import { Thrust } from '../force/Thrust.js';
import { StateCovariance } from './StateCovariance.js';
export declare class CovarianceSample {
    private _origin;
    private _samples;
    private matrix_;
    /**
     * Create a new [CovarianceSample] object from an inertial state, covariance
     * and optional force models for the origin state and samples.
     *
     * Two-body physics will be used if a force model is not provided.
     * @param state The origin state.
     * @param covariance The covariance.
     * @param originForceModel The force model for the origin state.
     * @param sampleForceModel The force model for the samples.
     */
    constructor(state: J2000, covariance: StateCovariance, originForceModel?: ForceModel, sampleForceModel?: ForceModel);
    get epoch(): Epoch;
    get state(): J2000;
    private _rebuildCovariance;
    propagate(epoch: EpochUTC): void;
    maneuver(maneuver: Thrust): void;
    desampleJ2000(): StateCovariance;
    desampleRIC(): StateCovariance;
}
