/**
 * @author @thkruz Theodore Kruczek
 * @license AGPL-3.0-or-later
 * @copyright (c) 2020-2024 Theodore Kruczek
 *
 * Orbital Object ToolKit is free software: you can redistribute it and/or modify it under the
 * terms of the GNU Affero General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * Orbital Object ToolKit is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with
 * Orbital Object ToolKit. If not, see <http://www.gnu.org/licenses/>.
 */
import { Matrix, Vector } from 'ootk-core';
/** Covariance Frame */
export declare enum CovarianceFrame {
    /** Earth-centered inertial */
    ECI = "eci",
    /** Radial-Intrack-Crosstrack */
    RIC = "ric"
}
export declare class StateCovariance {
    matrix: Matrix;
    frame: CovarianceFrame;
    /**
     * Create a new [StateCovariance] object given its covariance [matrix] and
     * [CovarianceFrame].
     * @param matrix The covariance matrix.
     * @param frame The covariance frame.
     * @returns A new [StateCovariance] object.
     */
    constructor(matrix: Matrix, frame: CovarianceFrame);
    static fromSigmas(sigmas: number[], frame: CovarianceFrame): StateCovariance;
    /**
     * Calculates the standard deviations (sigmas) of each element in the covariance matrix.
     * @returns A vector containing the standard deviations of each element in the covariance matrix.
     */
    sigmas(): Vector;
}
