/**
 * @author @thkruz Theodore Kruczek
 * @license AGPL-3.0-or-later
 * @copyright (c) 2020-2024 Theodore Kruczek
 *
 * Orbital Object ToolKit is free software: you can redistribute it and/or modify it under the
 * terms of the GNU Affero General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * Orbital Object ToolKit is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with
 * Orbital Object ToolKit. If not, see <http://www.gnu.org/licenses/>.
 */
import { EpochUTC, J2000, KilometersPerSecond, MetersPerSecond, Seconds, SecondsPerMeterPerSecond, Vector3D } from 'ootk-core';
import { Force } from './Force.js';
export declare class Thrust implements Force {
    center: EpochUTC;
    radial: MetersPerSecond;
    intrack: MetersPerSecond;
    crosstrack: MetersPerSecond;
    durationRate: SecondsPerMeterPerSecond;
    constructor(center: EpochUTC, radial: MetersPerSecond, intrack: MetersPerSecond, crosstrack: MetersPerSecond, durationRate?: SecondsPerMeterPerSecond);
    deltaV: Vector3D<KilometersPerSecond>;
    get magnitude(): MetersPerSecond;
    get duration(): Seconds;
    get start(): EpochUTC;
    get stop(): EpochUTC;
    acceleration(state: J2000): Vector3D;
    apply(state: J2000): J2000;
    get isImpulsive(): boolean;
}
