/**
 * @author @thkruz Theodore Kruczek
 * @license AGPL-3.0-or-later
 * @copyright (c) 2020-2024 Theodore Kruczek
 *
 * Orbital Object ToolKit is free software: you can redistribute it and/or modify it under the
 * terms of the GNU Affero General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * Orbital Object ToolKit is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with
 * Orbital Object ToolKit. If not, see <http://www.gnu.org/licenses/>.
 */
import { EpochUTC, EpochWindow, J2000 } from 'ootk-core';
import { ChebyshevCoefficients } from './ChebyshevCoefficients.js';
import { StateInterpolator } from './StateInterpolator.js';
/**
 * Compressed Chebyshev ephemeris interpolator.
 *
 * The ChebyshevInterpolator sacrifices state accuracy in order to gain
 * speed and memory requirements, so you can store many ephemerides in RAM
 * and interpolate through them quickly.
 *
 * Using more coefficients per revolution during lossy compression results
 * in increased accuracy and decreased performance.
 */
export declare class ChebyshevInterpolator extends StateInterpolator {
    private _coefficients;
    constructor(coefficients: ChebyshevCoefficients[]);
    private _calcSizeBytes;
    get sizeBytes(): number;
    interpolate(epoch: EpochUTC): J2000 | null;
    window(): EpochWindow;
    private _matchCoefficients;
}
