/**
 * @author @thkruz Theodore Kruczek
 * @license AGPL-3.0-or-later
 * @copyright (c) 2020-2024 Theodore Kruczek
 *
 * Orbital Object ToolKit is free software: you can redistribute it and/or modify it under the
 * terms of the GNU Affero General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * Orbital Object ToolKit is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with
 * Orbital Object ToolKit. If not, see <http://www.gnu.org/licenses/>.
 */
import { Seconds, Vector3D } from 'ootk-core';
export declare class CubicSpline {
    t0: Seconds;
    p0: Vector3D;
    m0: Vector3D;
    t1: Seconds;
    p1: Vector3D;
    m1: Vector3D;
    constructor(t0: Seconds, p0: Vector3D, m0: Vector3D, t1: Seconds, p1: Vector3D, m1: Vector3D);
    private position_;
    private velocity_;
    /**
     * Interpolates the position and velocity at a given time.
     * (km) and velocity (km/s) vectors at the provided time.
     * @param t The time value to interpolate at _(POSIX seconds)_.
     * @returns An array containing the interpolated position and velocity as Vector3D objects.
     */
    interpolate(t: Seconds): Vector3D[];
}
