/**
 * @author @thkruz Theodore Kruczek
 * @license AGPL-3.0-or-later
 * @copyright (c) 2020-2024 Theodore Kruczek
 *
 * Orbital Object ToolKit is free software: you can redistribute it and/or modify it under the
 * terms of the GNU Affero General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * Orbital Object ToolKit is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with
 * Orbital Object ToolKit. If not, see <http://www.gnu.org/licenses/>.
 */
import { EpochUTC, EpochWindow, J2000 } from 'ootk-core';
import { CubicSpline } from './CubicSpline.js';
import { StateInterpolator } from './StateInterpolator.js';
/**
 * Cubic spline ephemeris interpolator.
 *
 * The [CubicSplineInterpolator] is a very fast and accurate interpolator
 * at the expense of memory due to the cached spline pairs used in the
 * interpolation operation. Accuracy is significantly impacted when using
 * sparse ephemerides.
 */
export declare class CubicSplineInterpolator extends StateInterpolator {
    private _splines;
    constructor(_splines: CubicSpline[]);
    static fromEphemeris(ephemeris: J2000[]): CubicSplineInterpolator;
    get sizeBytes(): number;
    private matchSpline_;
    interpolate(epoch: EpochUTC): J2000 | null;
    window(): EpochWindow;
}
