/**
 * @author @thkruz Theodore Kruczek
 * @license AGPL-3.0-or-later
 * @copyright (c) 2020-2024 Theodore Kruczek
 *
 * Orbital Object ToolKit is free software: you can redistribute it and/or modify it under the
 * terms of the GNU Affero General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * Orbital Object ToolKit is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with
 * Orbital Object ToolKit. If not, see <http://www.gnu.org/licenses/>.
 */
import { EpochUTC, EpochWindow, J2000 } from 'ootk-core';
import { StateInterpolator } from './StateInterpolator.js';
export declare class LagrangeInterpolator extends StateInterpolator {
    private t_;
    private x_;
    private y_;
    private z_;
    private order;
    constructor(t: Float64Array, x: Float64Array, y: Float64Array, z: Float64Array, order?: number);
    /**
     * Creates a LagrangeInterpolator from an array of J2000 ephemeris data.
     * @param ephemeris - The array of J2000 ephemeris data.
     * @param order - The order of the LagrangeInterpolator. Default is 10.
     * @returns A new LagrangeInterpolator instance.
     */
    static fromEphemeris(ephemeris: J2000[], order?: number): LagrangeInterpolator;
    get sizeBytes(): number;
    interpolate(epoch: EpochUTC): J2000 | null;
    private static position_;
    private static velocity_;
    private static _getClosest;
    private slice_;
    window(): EpochWindow;
}
