/**
 * @author @thkruz Theodore Kruczek
 * @license AGPL-3.0-or-later
 * @copyright (c) 2020-2024 Theodore Kruczek
 *
 * Orbital Object ToolKit is free software: you can redistribute it and/or modify it under the
 * terms of the GNU Affero General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * Orbital Object ToolKit is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with
 * Orbital Object ToolKit. If not, see <http://www.gnu.org/licenses/>.
 */
import { EpochUTC, Seconds, SecondsPerMeterPerSecond } from 'ootk-core';
import { Thrust } from '../force/Thrust.js';
export declare class TwoBurnOrbitTransfer {
    vInit: number;
    vFinal: number;
    vTransA: number;
    vTransB: number;
    tTrans: Seconds;
    constructor(vInit: number, vFinal: number, vTransA: number, vTransB: number, tTrans: Seconds);
    /**
     * Calculates the parameters for a Hohmann transfer orbit between two circular orbits.
     * @param rInit The initial radius of the orbit. (km)
     * @param rFinal The final radius of the orbit. (km)
     * @returns An instance of TwoBurnOrbitTransfer containing the calculated parameters.
     */
    static hohmannTransfer(rInit: number, rFinal: number): TwoBurnOrbitTransfer;
    get deltaV(): number;
    /**
     * Calculates the two maneuver thrusts required for a two-burn orbit transfer.
     * @param epoch The epoch of the maneuver.
     * @param durationRate The duration rate of the maneuver (s/m/s).
     * @returns An array containing the two thrust objects representing the maneuvers.
     */
    toManeuvers(epoch: EpochUTC, durationRate?: SecondsPerMeterPerSecond): [Thrust, Thrust];
}
