/**
 * @author @thkruz Theodore Kruczek
 * @license AGPL-3.0-or-later
 * @copyright (c) 2020-2024 Theodore Kruczek
 *
 * Orbital Object ToolKit is free software: you can redistribute it and/or modify it under the
 * terms of the GNU Affero General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * Orbital Object ToolKit is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with
 * Orbital Object ToolKit. If not, see <http://www.gnu.org/licenses/>.
 */
import { LaunchDetails, OperationsDetails, OptionsParams, Satellite, SpaceCraftDetails } from 'ootk-core';
import { DetailedSatelliteParams } from '../types/types.js';
/**
 * Represents a detailed satellite object with launch, spacecraft, and operations details.
 */
export declare class DetailedSatellite extends Satellite {
    configuration: string;
    country: string;
    dryMass: string;
    equipment: string;
    launchDate: string;
    launchMass: string;
    launchSite: string;
    launchVehicle: string;
    lifetime: string | number;
    maneuver: string;
    manufacturer: string;
    mission: string;
    bus: string;
    motor: string;
    owner: string;
    payload: string;
    power: string;
    purpose: string;
    length: string;
    diameter: string;
    shape: string;
    span: string;
    user: string;
    source: string;
    vmag: number | null;
    rcs: number | null;
    altId: string;
    altName: string;
    constructor(info: DetailedSatelliteParams & LaunchDetails & OperationsDetails & SpaceCraftDetails, options?: OptionsParams);
    private static setSccNumTo0_;
    private initSpaceCraftDetails_;
    private initOperationDetails_;
    private initLaunchDetails_;
    /**
     * Returns the launch details of the satellite.
     * @returns An object containing the launch date, launch mass, launch site, and launch vehicle of the satellite.
     */
    getLaunchDetails(): LaunchDetails;
    /**
     * Returns an object containing the details of the operations.
     * @returns An object containing the user, mission, owner, and country details.
     */
    getOperationsDetails(): OperationsDetails;
    /**
     * Returns the space craft details.
     * @returns The space craft details.
     */
    getSpaceCraftDetails(): SpaceCraftDetails;
    clone(): DetailedSatellite;
}
