/**
 * @author @thkruz Theodore Kruczek
 * @license AGPL-3.0-or-later
 * @copyright (c) 2020-2024 Theodore Kruczek
 *
 * Orbital Object ToolKit is free software: you can redistribute it and/or modify it under the
 * terms of the GNU Affero General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * Orbital Object ToolKit is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with
 * Orbital Object ToolKit. If not, see <http://www.gnu.org/licenses/>.
 */
import { EpochUTC, J2000, Kilometers, Matrix, Radians, RAE, Vector, Vector3D } from 'ootk-core';
import { RandomGaussianSource } from '../operations/RandomGaussianSource.js';
import { Propagator } from '../propagator/Propagator.js';
import { Observation } from './Observation.js';
import { PropagatorPairs } from './PropagatorPairs.js';
export declare class ObservationRadar extends Observation {
    private _site;
    observation: RAE;
    private _noise;
    constructor(_site: J2000, observation: RAE, _noise?: Matrix);
    private static defaultNoise;
    get epoch(): EpochUTC;
    get site(): J2000;
    get noise(): Matrix;
    toVector(): Vector;
    clos(propagator: Propagator): number;
    ricDiff(propagator: Propagator): Vector3D;
    sample(random: RandomGaussianSource, sigma?: number): Observation;
    jacobian(propPairs: PropagatorPairs): Matrix;
    residual(propagator: Propagator): Matrix;
    /**
     * Create a noise matrix from the range, azimuth, and elevation standard
     * deviations _(kilometers/radians)_.
     * @param rngSigma - The range standard deviation _(kilometers)_.
     * @param azSigma - The azimuth standard deviation _(radians)_.
     * @param elSigma - The elevation standard deviation _(radians)_.
     * @returns The noise matrix.
     */
    static noiseFromSigmas(rngSigma: Kilometers, azSigma: Radians, elSigma: Radians): Matrix;
}
