/**
 * @author @thkruz Theodore Kruczek
 * @license AGPL-3.0-or-later
 * @copyright (c) 2020-2024 Theodore Kruczek
 *
 * Orbital Object ToolKit is free software: you can redistribute it and/or modify it under the
 * terms of the GNU Affero General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * Orbital Object ToolKit is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with
 * Orbital Object ToolKit. If not, see <http://www.gnu.org/licenses/>.
 */
import { DifferentiableFunction } from '../main.js';
export declare class GoldenSection {
    private static readonly _grInv;
    private static _check;
    /**
     * Search for an optimal input value for function [f] that minimizes the
     * output value.
     *
     * Takes [lower] and [upper] input search bounds, and an optional
     * search [tolerance].
     * @param f Function to optimize
     * @param lower Lower bound
     * @param upper Upper bound
     * @param root0 Root0
     * @param root0.tolerance Root0.tolerance
     * @param root0.solveMax Root0.solveMax
     * @returns The optimal input value.
     */
    static search(f: DifferentiableFunction, lower: number, upper: number, { tolerance, solveMax, }: {
        tolerance?: number;
        solveMax?: boolean;
    }): number;
}
