/**
 * @author @thkruz Theodore Kruczek
 * @license AGPL-3.0-or-later
 * @copyright (c) 2020-2024 Theodore Kruczek
 *
 * Orbital Object ToolKit is free software: you can redistribute it and/or modify it under the
 * terms of the GNU Affero General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * Orbital Object ToolKit is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with
 * Orbital Object ToolKit. If not, see <http://www.gnu.org/licenses/>.
 */
import { PolynomicalRegressionResult } from './PolynomicalRegressionResult.js';
export declare class PolynomialRegression {
    private constructor();
    private static _bayesInformationCriterea;
    /**
     * Optimize polynomial coefficients to fit data series [xs] and [ys] for the
     * provided polynomial [order].
     * @param xs x values
     * @param ys y values
     * @param order Polynomial order
     * @param root0 Root0
     * @param root0.printIter Root0.printIter
     * @returns The optimal input value.
     */
    static solve(xs: Float64Array, ys: Float64Array, order: number, { printIter }?: {
        printIter?: boolean;
    }): PolynomicalRegressionResult;
    /**
     * Optimize polynomial coefficients to fit data series [xs] and [ys], and
     * attempt to find an optimal order within the [minOrder] and
     * [maxOrder] bounds.
     * @param xs x values
     * @param ys y values
     * @param minOrder Minimum polynomial order
     * @param maxOrder Maximum polynomial order
     * @param root0 Root0
     * @param root0.printIter Root0.printIter
     * @returns The optimal input value.
     */
    static solveOrder(xs: Float64Array, ys: Float64Array, minOrder: number, maxOrder: number, { printIter }?: {
        printIter?: boolean;
    }): PolynomicalRegressionResult;
}
