/**
 * @author @thkruz Theodore Kruczek
 * @license AGPL-3.0-or-later
 * @copyright (c) 2020-2024 Theodore Kruczek
 *
 * Orbital Object ToolKit is free software: you can redistribute it and/or modify it under the
 * terms of the GNU Affero General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * Orbital Object ToolKit is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with
 * Orbital Object ToolKit. If not, see <http://www.gnu.org/licenses/>.
 */
import { EpochUTC, J2000, Kilometers, Vector3D } from 'ootk-core';
/**
 * Gibbs 3-position inital orbit determination.
 */
export declare class GibbsIOD {
    mu: number;
    constructor(mu?: number);
    /** Abort solve if position plane exceeds this value. */
    private static readonly coplanarThreshold_;
    /**
     * Attempt to create a state estimate from three inertial position vectors.
     *
     * Throws an error if the positions are not coplanar.
     * @param r1 Position vector 1.
     * @param r2 Position vector 2.
     * @param r3 Position vector 3.
     * @param t2 Time of position 2.
     * @param t3 Time of position 3.
     * @returns State estimate at time t2.
     */
    solve(r1: Vector3D<Kilometers>, r2: Vector3D<Kilometers>, r3: Vector3D<Kilometers>, t2: EpochUTC, t3: EpochUTC): J2000;
}
