/**
 * @author @thkruz Theodore Kruczek
 * @license AGPL-3.0-or-later
 * @copyright (c) 2020-2024 Theodore Kruczek
 *
 * Orbital Object ToolKit is free software: you can redistribute it and/or modify it under the
 * terms of the GNU Affero General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * Orbital Object ToolKit is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with
 * Orbital Object ToolKit. If not, see <http://www.gnu.org/licenses/>.
 */
import { J2000, Kilometers } from 'ootk-core';
import { ObservationOptical } from './../observation/ObservationOptical.js';
/**
 * Gooding angles-only initial orbit determination.
 *
 * Used for orbit determination from three optical observations.
 */
export declare class GoodingIOD {
    private readonly _mu;
    private readonly o1_;
    private readonly o2_;
    private readonly o3_;
    private vObserverPosition1_;
    private vObserverPosition2_;
    private vObserverPosition3_;
    private r_;
    private v_;
    private t_;
    private r1_;
    private r2_;
    private r3_;
    private rho1_;
    private rho2_;
    private rho3_;
    private d1_;
    private d3_;
    private facFiniteDiff_;
    private readonly _forceModel;
    constructor(o1: ObservationOptical, o2: ObservationOptical, o3: ObservationOptical, mu?: number);
    private _getPositionOnLoS2;
    private _modifyIterate;
    private _computeDerivatives;
    solve(r1Init: Kilometers, r3Init: Kilometers, nRev?: number, direction?: boolean): J2000;
    private _solveRangeProblem;
}
