/**
 * @author @thkruz Theodore Kruczek
 * @license AGPL-3.0-or-later
 * @copyright (c) 2020-2024 Theodore Kruczek
 *
 * Orbital Object ToolKit is free software: you can redistribute it and/or modify it under the
 * terms of the GNU Affero General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * Orbital Object ToolKit is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with
 * Orbital Object ToolKit. If not, see <http://www.gnu.org/licenses/>.
 */
import { EpochUTC, J2000, Seconds } from 'ootk-core';
import { Thrust } from '../force/Thrust.js';
import { VerletBlendInterpolator } from '../interpolator/VerletBlendInterpolator.js';
export declare abstract class Propagator {
    abstract propagate(epoch: EpochUTC): J2000;
    ephemeris(start: EpochUTC, stop: EpochUTC, interval?: Seconds): VerletBlendInterpolator;
    abstract reset(): void;
    abstract checkpoint(): number;
    abstract restore(index: number): void;
    abstract clearCheckpoints(): void;
    abstract get state(): J2000;
    maneuver(maneuver: Thrust, interval?: Seconds): J2000[];
    ephemerisManeuver(start: EpochUTC, finish: EpochUTC, maneuvers: Thrust[], interval?: Seconds): VerletBlendInterpolator;
    ascendingNodeEpoch(start: EpochUTC): EpochUTC;
    descendingNodeEpoch(start: EpochUTC): EpochUTC;
    apogeeEpoch(start: EpochUTC): EpochUTC;
    perigeeEpoch(start: EpochUTC): EpochUTC;
}
