/**
 * @author @thkruz Theodore Kruczek
 * @license AGPL-3.0-or-later
 * @copyright (c) 2020-2024 Theodore Kruczek
 *
 * Orbital Object ToolKit is free software: you can redistribute it and/or modify it under the
 * terms of the GNU Affero General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * Orbital Object ToolKit is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with
 * Orbital Object ToolKit. If not, see <http://www.gnu.org/licenses/>.
 */
import { EpochUTC, J2000, Seconds } from 'ootk-core';
import { ForceModel } from '../force/ForceModel.js';
import { Thrust } from '../force/Thrust.js';
import { VerletBlendInterpolator } from '../interpolator/VerletBlendInterpolator.js';
import { Propagator } from './Propagator.js';
export declare class RungeKutta4Propagator extends Propagator {
    private initState_;
    private forceModel_;
    private stepSize_;
    private cacheState_;
    private checkpoints_;
    /**
     * Create a new [RungeKutta4Propagator] object from an initial state vector and
     * along with an optional [ForceModel] and [stepSize] in seconds.
     * @param initState_ Initial state vector.
     * @param forceModel_ Numerical integration force model.
     * @param stepSize_ Integration step size _(seconds)_.
     * @param cacheState_ Cached state vector.
     * @param checkpoints_ Cached state vector checkpoints.
     */
    constructor(initState_: J2000, forceModel_?: ForceModel, stepSize_?: number, cacheState_?: J2000, checkpoints_?: J2000[]);
    setStepSize(seconds: number): void;
    setForceModel(forceModel: ForceModel): void;
    ephemerisManeuver(start: EpochUTC, finish: EpochUTC, maneuvers: Thrust[], interval?: Seconds): VerletBlendInterpolator;
    maneuver(maneuver: Thrust, interval?: number): J2000[];
    private _kFn;
    private _integrate;
    propagate(epoch: EpochUTC): J2000;
    reset(): void;
    get state(): J2000;
    checkpoint(): number;
    clearCheckpoints(): void;
    restore(index: number): void;
}
